@@ -1,7 +1,8 @@
 use std::sync::Arc;
 
-use crate::{types::ArcTx, Error};
+use crate::Error;
 use async_trait::async_trait;
+use fuel_core_interfaces::model::ArcTx;
 use fuel_core_interfaces::txpool::Subscriber;
 use parking_lot::RwLock;
 
