@@ -1,7 +1,7 @@
 use crate::containers::dependency::Dependency;
-use crate::containers::info::TxInfo;
 use crate::Error;
 use crate::{containers::price_sort::PriceSort, types::*, Config};
+use fuel_core_interfaces::model::{ArcTx, TxInfo};
 use fuel_core_interfaces::txpool::TxPoolDb;
 use std::collections::HashMap;
 use std::sync::Arc;
@@ -98,11 +98,15 @@ impl TxPool {
 
     /// remove transaction from pool needed on user demand. Low priority
     pub fn remove_by_tx_id(&mut self, tx_id: &TxId) -> Vec<ArcTx> {
-        if let Some(tx) = self.by_hash.get(tx_id) {
-            self.by_gas_price.remove(tx);
-            return self
+        if let Some(tx) = self.by_hash.remove(tx_id) {
+            let removed = self
                 .by_dependency
                 .recursively_remove_all_dependencies(&self.by_hash, tx.tx().clone());
+            for remove in removed.iter() {
+                self.by_gas_price.remove(remove);
+                self.by_hash.remove(&remove.id());
+            }
+            return removed;
         }
         Vec::new()
     }
